@@ -1,11 +1,5 @@
 PoisMixMean <-
 function(y, g, conds, s, lambda) {
-if(is.matrix(y) == FALSE & is.data.frame(y) == FALSE) 
-	stop(paste(sQuote("y"), "must be a matrix"))
-if(min(y) < 0 | sum(round(y)) != sum(y)) 
-	stop(paste(sQuote("y"), "must be a matrix made up of nonnegative counts"))
-if(min(rowSums(y)) == 0)
-	stop(paste("at least one observation in", sQuote("y"), "contains all 0's and must be removed from the data"))
 if(length(g) != 1)
 	stop(paste(sQuote("g"), "(the number of clusters) must be a nonnegative integer"))
 if(g < 0 | round(g) != g) 
