@@ -1,11 +1,6 @@
 logLikePoisMixDiff <-
 function(y, mean.new, pi.new, mean.old, pi.old) {
-if(is.matrix(y) == FALSE & is.data.frame(y) == FALSE) 
-	stop(paste(sQuote("y"), "must be a matrix"))
-if(min(y) < 0 | sum(round(y)) != sum(y)) 
-	stop(paste(sQuote("y"), "must be a matrix made up of nonnegative counts"))
-if(min(rowSums(y)) == 0)
-	stop(paste("at least one observation in", sQuote("y"), "contains all 0's and must be removed from the data"))
+
 if(length(mean.old) != length(pi.old)) 
 	stop(paste(sQuote("mean.old"), "must be a list of the same length as", sQuote("pi.old")))
 if(length(mean.new) != length(pi.new)) 
